# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.5.2] - 2021-12-13

### Added

* #23 Daemon functionality

### Changed

* Fixed issue with local dummy runner
* Fixed re-copy on pickup issue with deep templates

## [0.5.1] - 2021-10-31

### Added

* Ability to specify CLI based run arguments

### Changed

* Fixed issue with statuses

## [0.5.0] - 2021-10-07

_This release was a big collection of amendments from 0.4.0_

## [0.4.0] - 2021-02-06

### Added:

Initial release into the wild of the code, previously used only internally in BAS

[0.4.0]: https://github.com/JimCircadian/model-ensembler/releases/tag/v0.4.0
